@@ -1,4 +1,4 @@
-from .import_path import import_path
+import imptools
 
 
 def enable_relative():
@@ -38,11 +38,15 @@ def enable_relative():
   if __main__.__package__ is not None:
     return
 
+  # Skip if running from interactive interpreter.
+  if not hasattr(__main__, '__file__'):
+    return
+
   # Assume the module is simply the parent directory.
   root = pathlib.Path(__main__.__file__).parent
 
   # Import the module without polluting the Python import path.
-  import_path(root)
+  imptools.import_path(root)
 
   # Set the package variable so Python can resolve relative imports.
   __main__.__package__ = root.name
